import 'package:flutter/material.dart';
import 'package:ocg_app/src/widgets/ease_in_widget.dart';

class AppTabBar extends StatelessWidget {
  final List<String> values;
  final int currentIndex;
  final Function(int index) onChanged;

  const AppTabBar(
      {Key key,
      @required this.values,
      this.currentIndex = 0,
      @required this.onChanged})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.all(6),
      decoration: BoxDecoration(
          color: Color(0xffeeeeee), borderRadius: BorderRadius.circular(12)),
      child: Row(
        children: values
            .asMap()
            .keys
            .map((key) => Expanded(
                    child: buildTab(values[key], currentIndex == key, () {
                  onChanged(key);
                })))
            .toList(),
      ),
    );
  }

  Widget buildTab(String title, bool isSelected, Function() onTap) {
    return EaseInWidget(
      onTap: onTap,
      child: AnimatedContainer(
        duration: Duration(milliseconds: 0),
        margin: EdgeInsets.symmetric(horizontal: 6),
        decoration: BoxDecoration(
            color: isSelected ? Colors.white : Colors.transparent,
            boxShadow: isSelected
                ? [
                    BoxShadow(
                        color: Colors.black.withOpacity(0.1),
                        blurRadius: 6,
                        spreadRadius: 1)
                  ]
                : [],
            borderRadius: BorderRadius.circular(12)),
        alignment: Alignment.center,
        child: Text(
          "$title",
          style: TextStyle(
            color: Colors.black,
            fontSize: 14,
            fontWeight: FontWeight.w600,
          ),
        ),
      ),
    );
  }
}
